@@ -220,7 +220,7 @@ struct EM_descender
 	inline
 	void
 	handle_W_mer_occurrence_one_strand(
-		int global_pos,
+	    global_pos_t global_pos,
 		double Z_strand,
 		double g_n,
 		double lambda,
