@@ -2030,28 +2030,48 @@ class Algorithm(object):
 
     def _set_min_and_max_number_sites(self):
         "Configure our max and min number of sites options if user has not set them explicitly."
-        if not self.options.max_num_sites:            
-            # allow number of sites up to 3 * # sequences / 2, with a hard limit if not user-specified
-            hard_limit = 10000
-            self.options.max_num_sites = min(3 * len(self.input_sequences.seqs) / 2, hard_limit)
-            if hard_limit == self.options.max_num_sites:
-                logger.warning('Hit cap of %d on maximum number of sites, user can over-ride this with the --max-sites option. High values will slow STEME down.' % hard_limit)
+        if not self.options.max_num_sites:
+            # By default we will look for at most 3 * # seqs / 2 sites with a minimum of 2
+            self.options.max_num_sites = max(3 * len(self.input_sequences.seqs) / 2, 2)
             
-            # however if user has set minimum number of sites always have at least 50% more
+            # Check if we've exceeded the hard limit
+            hard_limit = 10000
+            if self.options.max_num_sites > hard_limit:
+                logger.warning('Implicit maximum number of sites (%d) is larger than hard limit (%d), capping at hard limit.', self.options.max_num_sites, hard_limit)
+                logger.warning('Hit cap of %d on maximum number of sites, user can over-ride this with the --max-sites option. High values will slow STEME down.' % hard_limit)
+                self.options.max_num_sites = hard_limit
+            
+            # however if user has set minimum number of sites always have at least double this
             if self.options.min_num_sites:
                 twice = 2 * self.options.min_num_sites
                 if self.options.max_num_sites < twice:
                     self.options.max_num_sites = twice
-                    logger.info('Maximum number of sites not explicitly set and is less than twice minimum. Increasing to %d', self.options.max_num_sites)
+                    logger.info('Maximum number of sites not explicitly set and is less than twice explicit minimum. Increasing to %d', self.options.max_num_sites)
                 
-            logger.info('Maximum number of sites not explicitly set. Was set to %d', self.options.max_num_sites)
-            
+            logger.info('Maximum number of sites not explicitly set. Was set to %d.', self.options.max_num_sites)
+        
         if not self.options.min_num_sites:
-            # Look for at least one site in every 10th sequence
-            # but always look for at least 2 sites unless max_num_sites is small
-            self.options.min_num_sites = max(len(self.input_sequences.seqs) / 10, min(2, self.options.max_num_sites))
-            logger.info('Minimum number of sites not explicitly set. Was set to %d', self.options.min_num_sites)
+            # By default we will look for at least one site in every 10th sequence
+            self.options.min_num_sites = len(self.input_sequences.seqs) / 10
+            
+            # but always go down to at least half the maximum number of sites
+            if self.options.min_num_sites > self.options.max_num_sites / 2:
+                logger.info('Reseting minimum number of sites to half of maximum.')
+                self.options.min_num_sites = self.options.max_num_sites / 2
 
+            # looking for less than 2 sites makes no sense            
+            if self.options.min_num_sites < 2:
+                logger.info('Makes no sense to have minimum number of sites less than two.')
+                self.options.min_num_sites = 2
+                
+            logger.info('Minimum number of sites not explicitly set. Was set to %d.', self.options.min_num_sites)
+
+        if self.options.max_num_sites < 2:
+            raise RuntimeError('Bad configuration option max-num-sites: Makes no sense to look for a motif formed of less than 2 sites.')
+            
+        if self.options.min_num_sites < 2:
+            raise RuntimeError('Bad configuration option min-num-sites: Makes no sense to look for a motif formed of less than 2 sites.')
+            
         if self.options.min_num_sites > self.options.max_num_sites:
             raise RuntimeError('Bad configuration options: Minimum number of sites should be less than maximum number of sites.')
         
